==> daemonshogi-0.1.3.tar.gz: daemonshogi-0.1.3/src/si/comaccess.h <==
/* SI SHOGI Library
   Copyright (C) 2002 Masahiko Tokita
   This file is part of the SI SHOGI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.w

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with The Daemonshogi; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */
/*
 * comaccess.h
 * $Source: /cvs/si/comaccess.h,v $
 * $Id: comaccess.h,v 1.6 2002/09/11 21:17:23 mik Exp $
 */

#include "si.h"

#ifdef USE_SERIAL

#ifndef _COMACCESS_H_
#define _COMACCESS_H_

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#include <termios.h>

/** ܡ졼Ȥ 1200 baud ꤹ */
#define BAUDRATE B1200
#define _POSIX_SOURCE 1  /* POSIX Υ */

/** ǥХե̾κʸ */
#define DEVICENAMESIZE 1024

/** COMݡȤȤä̿жɤΤι¤ */
typedef struct {
  /** ǥХեΥե롦ǥץ */
  int fd;
  /** ǥХե̾ */
  char DEVICENAME[DEVICENAMESIZE];
  /** ХååѤΥߥʥ */
  struct termios oldtio;
  /** ߥʥ */
  struct termios newtio;
} COMACCESS;

COMACCESS *newCOMACCESS(void);
void freeCOMACCESS(COMACCESS *ca);
void initCOMACCESS(COMACCESS *ca);
void caSetDEVICENAME(COMACCESS *ca, char *str);
void caStart(COMACCESS *ca);
void caClose(COMACCESS *ca);
int caAccept(COMACCESS *ca, char *buf);
int caSend(COMACCESS *ca, char *str);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _COMACCESS_H_ */

#endif /* USE_SERIAL */

==> daemonshogi-0.1.4.tar.gz: daemonshogi-0.1.4/src/si/comaccess.h <==
/* SI SHOGI Library
   Copyright (C) 2002 Masahiko Tokita
   This file is part of the SI SHOGI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.w

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with The Daemonshogi; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */
/*
 * comaccess.h
 * $Source: /cvsroot/daemonshogi/daemonshogi/src/si/comaccess.h,v $
 * $Id: comaccess.h,v 1.1.1.1 2005/12/09 09:03:07 tokita Exp $
 */

#include "si.h"

#ifdef USE_SERIAL

#ifndef _COMACCESS_H_
#define _COMACCESS_H_

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#include <termios.h>

/** ܡ졼Ȥ 1200 baud ꤹ */
#define BAUDRATE B1200
#define _POSIX_SOURCE 1  /* POSIX Υ */

/** ǥХե̾κʸ */
#define DEVICENAMESIZE 1024

/** COMݡȤȤä̿жɤΤι¤ */
typedef struct {
  /** ǥХեΥե롦ǥץ */
  int fd;
  /** ǥХե̾ */
  char DEVICENAME[DEVICENAMESIZE];
  /** ХååѤΥߥʥ */
  struct termios oldtio;
  /** ߥʥ */
  struct termios newtio;
} COMACCESS;

COMACCESS *newCOMACCESS(void);
void freeCOMACCESS(COMACCESS *ca);
void initCOMACCESS(COMACCESS *ca);
void caSetDEVICENAME(COMACCESS *ca, char *str);
void caStart(COMACCESS *ca);
void caClose(COMACCESS *ca);
int caAccept(COMACCESS *ca, char *buf);
int caSend(COMACCESS *ca, char *str);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _COMACCESS_H_ */

#endif /* USE_SERIAL */
